# Contributing
## Development environment
To install the development environment, please follow these steps:

```bash
pip install -r requirements_dev.txt
pre-commit install
pre-commit run --all-files
```

Then, the pre-commit will run automatically when you commit.
